/*
// Licensed to Julian Hyde under one or more contributor license
// agreements. See the NOTICE file distributed with this work for
// additional information regarding copyright ownership.
//
// Julian Hyde licenses this file to you under the Apache License,
// Version 2.0 (the "License"); you may not use this file except in
// compliance with the License. You may obtain a copy of the License at:
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
*/
package org.eigenbase.rex;

import org.eigenbase.reltype.*;


/**
 * Reference to the current row of a correlating relational expression.
 *
 * <p>Correlating variables are introduced when performing nested loop joins.
 * Each row is received from one side of the join, a correlating variable is
 * assigned a value, and the other side of the join is restarted.</p>
 *
 * @author jhyde
 * @version $Id$
 * @since Nov 24, 2003
 */
public class RexCorrelVariable
    extends RexVariable
{
    //~ Constructors -----------------------------------------------------------

    RexCorrelVariable(
        String varName,
        RelDataType type)
    {
        super(varName, type);
    }

    //~ Methods ----------------------------------------------------------------

    public RexCorrelVariable clone()
    {
        return new RexCorrelVariable(name, type);
    }

    public <R> R accept(RexVisitor<R> visitor)
    {
        return visitor.visitCorrelVariable(this);
    }
}

// End RexCorrelVariable.java
