/*
// Licensed to Julian Hyde under one or more contributor license
// agreements. See the NOTICE file distributed with this work for
// additional information regarding copyright ownership.
//
// Julian Hyde licenses this file to you under the Apache License,
// Version 2.0 (the "License"); you may not use this file except in
// compliance with the License. You may obtain a copy of the License at:
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
*/
package org.eigenbase.sql.fun;

import org.eigenbase.sql.*;
import org.eigenbase.sql.type.*;
import org.eigenbase.sql.validate.*;


/**
 * Base class for functions such as "USER", "CURRENT_ROLE", and "CURRENT_PATH".
 *
 * @author John V. Sichi
 * @version $Id$
 */
public class SqlStringContextVariable
    extends SqlFunction
{
    //~ Constructors -----------------------------------------------------------

    protected SqlStringContextVariable(String name)
    {
        super(
            name,
            SqlKind.OTHER_FUNCTION,
            SqlTypeStrategies.rtiVarchar2000,
            null,
            SqlTypeStrategies.otcNiladic,
            SqlFunctionCategory.System);
    }

    //~ Methods ----------------------------------------------------------------

    public SqlSyntax getSyntax()
    {
        return SqlSyntax.FunctionId;
    }

    // All of the string constants are monotonic.
    public SqlMonotonicity getMonotonicity(
        SqlCall call,
        SqlValidatorScope scope)
    {
        return SqlMonotonicity.Constant;
    }

    // Plans referencing context variables should never be cached
    public boolean isDynamicFunction()
    {
        return true;
    }
}

// End SqlStringContextVariable.java
